"""
Module containing the scaling functions.
"""

import time

def get_mp_results(population, cpu_list, amt_repeats, total_systems):
    """
    Function that runs a population <amt_repeats> for each
    cpu amount (which is picked from cpu_list)
    """

    population.set(evolution_type="mp")
    mp_dict = {}
    for cpu_amt in cpu_list:

        mp_times = []

        population.set(amt_cores=cpu_amt)

        #
        for _ in range(amt_repeats):
            total_mp_start = time.time()
            population.evolve_population()
            total_mp = time.time() - total_mp_start

            print(
                "MP ({} nodes) run with {} systems: {}".format(
                    cpu_amt, total_systems, total_mp
                )
            )
            mp_times.append(total_mp)

        mp_dict[cpu_amt] = mp_times

    return mp_dict

def get_linear_results(population, amt_repeats, total_systems):
    """
    Function that runs the population linearly (using 1 core) <amt_repeats> times
    """

    population.set(evolution_type="linear")
    linear_times = []
    for _ in range(amt_repeats):
        total_lin_start = time.time()
        population.evolve_population()
        total_lin = time.time() - total_lin_start

        print(
            "linear run with {} systems: {}".format(
                total_systems, total_lin
            )
        )
        linear_times.append(total_lin)

    return linear_times
